```
Usage: vcd vapp network update-dns [OPTIONS] <vapp-name> <network-name>

Options:
  --dns1 <ip>              IP of the primary dns server
  --dns2 <ip>              IP of the secondary dns server
  --dns-suffix dns-suffix  dns suffix
  -h, --help               Show this message and exit.

```
